'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2009
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'
Imports System.Text
Imports System.Web.UI.WebControls
Imports System.Text.RegularExpressions
Imports System.Globalization

Imports DotNetNuke
Imports DotNetNuke.Common.Utilities
Imports DotNetNuke.Entities.Modules
Imports DotNetNuke.Entities.Modules.Actions
Imports DotNetNuke.Services.Exceptions
Imports DotNetNuke.Services.Localization
Imports DotNetNuke.Services.Tokens
Imports DotNetNuke.Security
Imports System.Collections.Generic

Namespace DotNetNuke.Modules.Announcements

    Partial Public Class Announcements
        Inherits AnnouncementsBase
        Implements IActionable

#Region "Private Members"

        Private arrAnnouncements As List(Of Model.Announcement)
        Private viewTypeCacheKey As String = ModuleController.CacheKey(TabModuleId) + "_viewType"

        ''' <summary>
        ''' viewType returns the viewType for this module. For non editors, the value comes from a setting, and is cached
        ''' for Editors, the setting comes from a setting if page.IsPostback is false, otherwise it comes from 
        ''' the selected value of the dropdownlist
        ''' </summary>
        ''' <value></value>
        ''' <returns></returns>
        ''' <history>
        '''     [erikvb]      09/06/2008    described
        ''' </history>
        Private ReadOnly Property viewType() As ViewTypes
            Get

                Dim returnValue As Object = DirectCast([Enum].Parse(GetType(ViewTypes), getSetting("defaultViewType", [Enum].GetName(GetType(ViewTypes), ViewTypes.Current))), ViewTypes)

                If PortalSecurity.HasNecessaryPermission(Security.SecurityAccessLevel.Edit, PortalSettings, Me.ModuleConfiguration, UserInfo) Then
                    If Page.IsPostBack Then
                        returnValue = DirectCast([Enum].Parse(GetType(ViewTypes), ddlViewType.SelectedValue), ViewTypes)
                    End If
                Else
                    Dim CachedViewType As Object = DataCache.GetCache(viewTypeCacheKey)
                    If CachedViewType Is Nothing Then
                        If Not Common.Globals.PerformanceSetting = Common.Globals.PerformanceSettings.NoCaching Then
                            DataCache.SetCache(viewTypeCacheKey, returnValue)
                        End If
                    Else
                        returnValue = CachedViewType
                    End If
                End If

                Return DirectCast(returnValue, ViewTypes)
            End Get
        End Property

        Private ReadOnly Property editEnabled() As Boolean
            Get
                Dim blnPreview As Boolean = (PortalSettings.UserMode = Entities.Portals.PortalSettings.Mode.View)
                Return (Not blnPreview) AndAlso PortalSecurity.HasNecessaryPermission(Security.SecurityAccessLevel.Edit, PortalSettings, Me.ModuleConfiguration, UserInfo)

            End Get
        End Property
#End Region

#Region "Protected Methods"

        ''' <summary>
        ''' 
        ''' getSetting gets a named modulesetting. if the setting is not found, defaulvalue is used
        ''' </summary>
        ''' <param name="settingName"></param>
        ''' <param name="defaultValue"></param>
        ''' <returns></returns>
        ''' <history>
        '''     [erikvb]      09/06/2008    created
        ''' </history>
        Protected Function getSetting(ByVal settingName As String, Optional ByVal defaultValue As String = "") As String
            Dim returnValue As String = defaultValue
            If Settings.Contains(settingName) Then
                returnValue = Settings(settingName).ToString
            End If
            Return returnValue
        End Function

        ''' <summary>
        ''' bindData loops through all announcements and parses the template for each announcement
        ''' </summary>
        ''' <history>
        '''     [erikvb]      09/06/2008    described
        ''' </history>
        Protected Sub BindData()
            Dim output As New StringBuilder

            ' bind data
            Dim datStartDate As Date = Null.NullDate

            If getSetting("history") <> "" Then
                datStartDate = DateAdd(DateInterval.Day, -(Integer.Parse(getSetting("history"))), Now)
            End If

            Dim announcements As New AnnouncementsController

            Select Case viewType
                Case ViewTypes.Current
                    arrAnnouncements = announcements.GetCurrentAnnouncements(ModuleId, datStartDate)
                Case ViewTypes.Expired
                    arrAnnouncements = announcements.GetExpiredAnnouncements(ModuleId)
                Case ViewTypes.Future
                    arrAnnouncements = announcements.GetAnnouncements(ModuleId, Now, Null.NullDate)
                Case ViewTypes.All
                    arrAnnouncements = announcements.GetAnnouncements(ModuleId, Null.NullDate, Null.NullDate)
            End Select


            Dim dnnTokenReplace As Services.Tokens.TokenReplace = Nothing
            If Template.TokenReplaceNeeded Then
                dnnTokenReplace = New Services.Tokens.TokenReplace(Scope.DefaultSettings, CultureInfo.CurrentCulture.Name, PortalSettings, UserInfo)
            End If
            Dim altItemTemplateAvailable As Boolean = Not String.IsNullOrEmpty(Template.AltItemTemplate)
            If dnnTokenReplace IsNot Nothing Then
                output.Append(dnnTokenReplace.ReplaceEnvironmentTokens(Template.HeaderTemplate))
            End If
            Dim counter As Integer = 0
            Dim tokenReplace As New AnnouncementsTokenReplace()
            For Each announcement As Model.Announcement In arrAnnouncements
                'we have to pass IsEditable to the announcement, because it is used to draw the edit icon
                announcement.IsEditable = editEnabled

                'Create a Token Replace and replace the tokens for this template
                tokenReplace.SetPropertySource(announcement)
                If (counter Mod 2 = 0) Or (Not altItemTemplateAvailable) Then
                    output.Append(tokenReplace.ReplaceAnnouncmentTokens(Template.ItemTemplate))
                Else
                    output.Append(tokenReplace.ReplaceAnnouncmentTokens(Template.AltItemTemplate))
                End If
                If (dnnTokenReplace IsNot Nothing) AndAlso (counter < arrAnnouncements.Count - 1) Then
                    output.Append(dnnTokenReplace.ReplaceEnvironmentTokens(Template.Separator))
                End If
                counter += 1

            Next
            If dnnTokenReplace IsNot Nothing Then
                output.Append(dnnTokenReplace.ReplaceEnvironmentTokens(Template.FooterTemplate))
            End If

            Me.litAnnouncements.Text = output.ToString
        End Sub

#End Region

#Region "Event Handlers"

        ''' -----------------------------------------------------------------------------
        ''' <summary>
        ''' Page_Load runs when the control is loaded
        ''' </summary>
        ''' <history>
        ''' 	[cnurse]	08/15/2007  Converted to a WAP project for Demo
        ''' </history>
        ''' -----------------------------------------------------------------------------
        Protected Overrides Sub OnLoad(ByVal e As System.EventArgs)
            'Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Me.Load
            MyBase.OnLoad(e)
            Try

                If Not Page.IsPostBack Then

                    Me.viewtypeSelector.Visible = editEnabled
                    If editEnabled Then
                        ' check templates for [EDIT] token
                        Dim modified As Boolean = False
                        If Template.ItemTemplate.ToLowerInvariant.IndexOf("[edit]") = -1 Then
                            Template.ItemTemplate = Regex.Replace(Template.ItemTemplate, Regex.Escape("[TITLE]"), "[EDIT][TITLE]", RegexOptions.IgnoreCase)
                            modified = True
                        End If
                        If Template.AltItemTemplate.Length > 0 AndAlso Template.AltItemTemplate.ToLowerInvariant.IndexOf("[edit]") = -1 Then
                            Template.AltItemTemplate = Regex.Replace(Template.AltItemTemplate, Regex.Escape("[TITLE]"), "[EDIT][TITLE]", RegexOptions.IgnoreCase)
                            modified = True
                        End If
                        If modified Then
                            Template.UpdateTemplate()
                        End If
                        If Template.ItemTemplate.ToLowerInvariant.IndexOf("[edit]") = -1 Then
                            Skins.Skin.AddModuleMessage(Me, Localization.GetString("NoEditToken.Error", LocalResourceFile), Skins.Controls.ModuleMessage.ModuleMessageType.YellowWarning)
                        End If

                        'build viewtypes dropdownlist
                        Dim i As [Enum]
                        For Each i In [Enum].GetValues(GetType(ViewTypes))
                            ddlViewType.Items.Add(New ListItem(Localization.GetString([Enum].GetName(GetType(ViewTypes), i), LocalResourceFile), [Enum].GetName(GetType(ViewTypes), i)))
                        Next i
                        Me.ddlViewType.SelectedValue = [Enum].GetName(GetType(ViewTypes), viewType)
                    End If

                End If

                BindData()
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub


#End Region

#Region "IActionable Implementation"

        ''' -----------------------------------------------------------------------------
        ''' <summary>
        ''' Gets the modules custom Actions
        ''' </summary>
        ''' <history>
        ''' 	[cnurse]	08/15/2007  Converted to a WAP project for Demo
        '''     [erikvb]    06/09/2008  modified action icon to plus icon
        ''' </history>
        ''' -----------------------------------------------------------------------------
        Public ReadOnly Property ModuleActions() As Actions.ModuleActionCollection Implements IActionable.ModuleActions
            Get
                Dim Actions As New Actions.ModuleActionCollection
                Actions.Add(GetNextActionID, Localization.GetString(ModuleActionType.AddContent, LocalResourceFile), ModuleActionType.AddContent, "", "add.gif", EditUrl(), False, Security.SecurityAccessLevel.Edit, True, False)
                Actions.Add(GetNextActionID, "~", "")
                Return Actions
            End Get
        End Property

#End Region


    End Class

End Namespace